@@ -17,16 +17,11 @@ class About : public Gtk::AboutDialog
 {
 	public:
 
-	static void instance();
+	About();
 
 	private:
 
-	About();
-	~About();
-
-	static About* spAbout;
-
-	void kill(int);
+	void response(int);
 };
 
 } // namespace Gpaco
