@@ -15,8 +15,6 @@
 #include "filestreeview.h"
 #include <sstream>
 #include <algorithm>
-#include <gtkmm/liststore.h>
-#include <gtkmm/uimanager.h>
 #include <gtkmm/actiongroup.h>
 #include <gtkmm/menu.h>
 #include <gtkmm/stock.h>
@@ -46,7 +44,11 @@ static bool isRegular(string const&);
 
 FilesTreeView::FilesTreeView(Pkg& pkg)
 :
-	TreeView(),
+	Gtk::TreeView(),
+	mpMenu(NULL),
+	mpUIManager(Gtk::UIManager::create()),
+	mpActionGroup(Gtk::ActionGroup::create()),
+	mpSelection(get_selection()),
 	mPkg(pkg),
 	mColumns(),
 	mpModelAll(Gtk::ListStore::create(mColumns)),
@@ -59,7 +61,11 @@ FilesTreeView::FilesTreeView(Pkg& pkg)
 	mpActionUncompress(Gtk::Action::create("Uncompress", "_Uncompress")),
 	mpActionRemove(Gtk::Action::create("Remove", Gtk::Stock::DELETE, "_Remove..."))
 {
+	mpSelection->set_mode(Gtk::SELECTION_MULTIPLE);
+	set_rules_hint();
+
 	Glib::RefPtr<Gtk::ListStore>* pModel[3] = { &mpModelAll, &mpModelInst, &mpModelMiss };
+
 	for (int i = 0; i < 3; ++i) {
 		(*pModel[i])->set_sort_func(COL_STATUS, mem_fun(*this, &FilesTreeView::statusSortFunc));
 		(*pModel[i])->set_sort_func(COL_NAME, mem_fun(*this, &FilesTreeView::nameSortFunc));
@@ -116,8 +122,8 @@ FilesTreeView::FilesTreeView(Pkg& pkg)
 		pActionSelectAll(Gtk::Action::create("SelectAll", "Select _all")),
 		pActionUnselectAll(Gtk::Action::create("UnselectAll", "U_nselect all"));
 
-	mpActionGroup->add(pActionSelectAll, mem_fun(*this, &TreeView::selectAll));
-	mpActionGroup->add(pActionUnselectAll, mem_fun(*this, &TreeView::unselectAll));
+	mpActionGroup->add(pActionSelectAll, mem_fun(*this, &FilesTreeView::selectAll));
+	mpActionGroup->add(pActionUnselectAll, mem_fun(*this, &FilesTreeView::unselectAll));
 
 	mpUIManager->insert_action_group(mpActionGroup);
 
@@ -151,6 +157,19 @@ FilesTreeView::~FilesTreeView()
 { }
 
 
+void FilesTreeView::unselectAll()
+{
+	mpSelection->unselect_all();
+	writeLabel();
+}
+
+void FilesTreeView::selectAll()
+{
+	mpSelection->select_all();
+	writeLabel();
+}
+
+
 void FilesTreeView::writeLabel() const
 {
 	if ((*mppModel)->children().empty()) {
@@ -510,7 +529,7 @@ bool FilesTreeView::onPopupMenu(GdkEvent*)
 {
 	g_assert(!(*mppModel)->children().empty());
 
-	bool vis = countSelected();
+	bool vis = mpSelection->count_selected_rows();
 	mpActionStrip		->set_visible(vis);
 	mpActionCompress	->set_visible(vis);
 	mpActionUncompress	->set_visible(vis);
@@ -559,7 +578,7 @@ bool FilesTreeView::on_key_press_event(GdkEventKey* e)
 	switch (e->keyval) {
 		case GDK_Delete:
 		case GDK_BackSpace:
-			if (countSelected()) {
+			if (mpSelection->count_selected_rows()) {
 				onRemove();
 				done = true;
 			}
