@@ -15,25 +15,23 @@
 
 namespace Gpaco {
 
+class MainWindow;
+
 class Preferences : public Gtk::Dialog
 {
 	public:
 
-	static void instance();
+	Preferences(MainWindow&);
 
 	private:
 
-	Preferences();
-	~Preferences();
-
-	static Preferences* spPreferences;
-
-	Gtk::CheckButton*	mButtonColumns[MainTreeView::N_COLS];
+	Gtk::CheckButton*	mButtons[MainTreeView::N_COLS];
 	Gtk::CheckButton	mButtonHour;
+	MainWindow&			mMainWindow;
 
 	void response(int id);
 	void ok();
-
+	void onButtonClicked();
 };
 
 } // namespace Gpaco
