@@ -10,7 +10,6 @@
 #define PACO_LOG_H
 
 #include "options.h"
-#include "pkgset.h"
 #include <iosfwd>
 #include <set>
 
@@ -62,10 +61,6 @@ class Log
 		std::string const&	mInclude;
 		std::string const&	mExclude;
 		bool				mLogMissing;
-		bool				mIgnoreShared;
-		PkgSet				mPkgSet;
-
-		bool isShared(std::string const&);
 	};
 
 	friend class Excluder;
